@@ -84,12 +84,12 @@ neWeight <- function (object, ...)
 # ## example using vglm (yielding identical results as with glm)
 # library(VGAM)
 # fit.vglm <- vglm(negaff ~ att + gender + educ + age, 
-#                  family = gaussianff, data = UPBdata)
+#                  family = uninormal, data = UPBdata)
 # weightData2 <- neWeight(fit.vglm, nRep = 2)
 #
 #' \dontshow{
 #' library(VGAM) 
-# expData <- neWeight(negaff ~ factor(attbin) + gender + educ + age, family = gaussianff, data = UPBdata, FUN = vglm)
+# expData <- neWeight(negaff ~ factor(attbin) + gender + educ + age, family = uninormal, data = UPBdata, FUN = vglm)
 # neMod <- neModel(UPB ~ attbin0 + attbin1 + gender + educ + age, family = binomial, expData = expData, nBoot = 2)
 #  
 #' fit1 <- glm(negaff ~ att + gender + educ + age, data = UPBdata)
@@ -101,13 +101,13 @@ neWeight <- function (object, ...)
 #' head(w1); head(w1f)
 #'
 # # test vglm (vglm is also vgam class, but not other way around!)
-# fit1b <- vgam(negaff ~ att + gender + educ + age, family = gaussianff, data = UPBdata)
+# fit1b <- vgam(negaff ~ att + gender + educ + age, family = uninormal, data = UPBdata)
 # expData1b <- neWeight(fit1b)
 # head(attr(expData1, "weights")); head(attr(expData1b, "weights"))
-# fit1b <- vgam(negaff ~ s(att) + gender + educ + age, family = gaussianff, data = UPBdata)
+# fit1b <- vgam(negaff ~ s(att) + gender + educ + age, family = uninormal, data = UPBdata)
 # expData1b <- neWeight(fit1b)
 # head(attr(expData1, "weights")); head(attr(expData1b, "weights"))
-# expData1bf <- neWeight(negaff ~ s(att) + gender + educ + age, FUN = vgam, family = gaussianff, data = UPBdata)
+# expData1bf <- neWeight(negaff ~ s(att) + gender + educ + age, FUN = vgam, family = uninormal, data = UPBdata)
 # head(attr(expData1b, "weights")); head(attr(expData1bf, "weights"))
 #' ##
 #'
@@ -237,11 +237,11 @@ neWeight.default <- function (object, formula, data, nRep = 5, xSampling = c("qu
     family <- if (inherits(fit, "vglm")) 
         fit@family@vfamily[1] 
     else fit$family$family
-    family <- c("gaussian", "binomial", "poisson", "multinomial")[mapply(function(x,
-        y) grepl(y, x), as.character(family), c("gaussian", "binomial",
+    family <- c("gaussian", "gaussian", "binomial", "poisson", "multinomial")[mapply(function(x,
+        y) grepl(y, x), as.character(family), c("gaussian", "uninormal", "binomial",
         "poisson", "multinomial"))]
     dispersion <- if (inherits(fit, "vglm")) 
-        fit@misc$dispersion
+        fit@dispersion
     else if (inherits(fit, "SuperLearner") & family == "binomial")
         1
     else summary(fit)$dispersion
@@ -255,7 +255,7 @@ neWeight.default <- function (object, formula, data, nRep = 5, xSampling = c("qu
          binomial = function(x) {if (is.factor(x)) x <- as.numeric(x) - 1
          return(dbinom(x, size = 1, prob = unlist(predictFUN(fit, newdata = wrapFUN(expData), type = type)[ind])))}, 
          poisson = function(x) dpois(x, lambda = unlist(predictFUN(fit, newdata = wrapFUN(expData), type = type)[ind])),
-         multinomial = function(x) {pred <- unlist(predictFUN(fit, newdata = wrapFUN(expData), type = type)[ind])
+         multinomial = function(x) {pred <- unlist(predictFUN(fit, newdata = wrapFUN(expData), type = type)[ind, ])
          return(sapply(1:nrow(expData), function(i) pred[i, as.character(x[i])]))})
     expData[, vartype$X] <- expData[, vartype$Xexp[2]]
     weightsNum <- dfun(expData[, vartype$M])
@@ -336,7 +336,7 @@ neWeight.default <- function (object, formula, data, nRep = 5, xSampling = c("qu
 # ## example using vglm (yielding identical results as with glm)
 # library(VGAM)
 # weightData2 <- neWeight(negaff ~ att + gender + educ + age, 
-#                         family = gaussianff, data = UPBdata, nRep = 2, FUN = vglm)
+#                         family = uninormal, data = UPBdata, nRep = 2, FUN = vglm)
 #' @export
 neWeight.formula <- function (object, family, data, FUN = glm, nRep = 5, xSampling = c("quantiles", 
     "random"), xFit, percLim = c(0.05, 0.95), ...) 
